@@ -9,13 +9,13 @@ from cfnlint.rules.common import approaching_number_limit
 class LimitNumber(CloudFormationLintRule):
     """Check maximum Resource limit"""
 
-    id = 'I3010'
-    shortdesc = 'Resource limit'
+    id = "I3010"
+    shortdesc = "Resource limit"
     description = (
-        'Check the number of Resources in the template is approaching the upper limit'
+        "Check the number of Resources in the template is approaching the upper limit"
     )
-    source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cloudformation-limits.html'
-    tags = ['resources', 'limits']
+    source_url = "https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cloudformation-limits.html"
+    tags = ["resources", "limits"]
 
     def match(self, cfn):
-        return approaching_number_limit(cfn, 'Resources')
+        return approaching_number_limit(cfn, "Resources")
